summaryrefslogtreecommitdiffstats
path: root/src/PolarSSL++/CryptoKey.h
diff options
context:
space:
mode:
authormadmaxoft <github@xoft.cz>2014-05-01 15:21:41 +0200
committermadmaxoft <github@xoft.cz>2014-05-01 15:21:41 +0200
commit1587b21edded56dbfb88150500336c2853b460c6 (patch)
tree544cd9d1aece0e7902739b30a75e372506d775fa /src/PolarSSL++/CryptoKey.h
parentFixed crashes in the SSL HTTP connection. (diff)
downloadcuberite-1587b21edded56dbfb88150500336c2853b460c6.tar
cuberite-1587b21edded56dbfb88150500336c2853b460c6.tar.gz
cuberite-1587b21edded56dbfb88150500336c2853b460c6.tar.bz2
cuberite-1587b21edded56dbfb88150500336c2853b460c6.tar.lz
cuberite-1587b21edded56dbfb88150500336c2853b460c6.tar.xz
cuberite-1587b21edded56dbfb88150500336c2853b460c6.tar.zst
cuberite-1587b21edded56dbfb88150500336c2853b460c6.zip
Diffstat (limited to '')
-rw-r--r--src/PolarSSL++/CryptoKey.h (renamed from src/PolarSSL++/PublicKey.h)18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/PolarSSL++/PublicKey.h b/src/PolarSSL++/CryptoKey.h
index df52a4143..9c298e501 100644
--- a/src/PolarSSL++/PublicKey.h
+++ b/src/PolarSSL++/CryptoKey.h
@@ -1,7 +1,7 @@
// PublicKey.h
// Declares the cPublicKey class representing a RSA public key in PolarSSL
@@ -16,22 +16,22 @@
-class cPublicKey
+class cCryptoKey
{
friend class cSslContext;
public:
/** Constructs an empty key instance. Before use, it needs to be filled by ParsePublic() or ParsePrivate() */
- cPublicKey(void);
+ cCryptoKey(void);
/** Constructs the public key out of the DER- or PEM-encoded pubkey data */
- cPublicKey(const AString & a_PublicKeyData);
+ cCryptoKey(const AString & a_PublicKeyData);
/** Constructs the private key out of the DER- or PEM-encoded privkey data, with the specified password.
If a_Password is empty, no password is assumed. */
- cPublicKey(const AString & a_PrivateKeyData, const AString & a_Password);
+ cCryptoKey(const AString & a_PrivateKeyData, const AString & a_Password);
- ~cPublicKey();
+ ~cCryptoKey();
/** Decrypts the data using the stored public key
Both a_EncryptedData and a_DecryptedData must be at least <KeySizeBytes> bytes large.
@@ -58,7 +58,7 @@ public:
bool IsValid(void) const;
protected:
- /** The public key PolarSSL representation */
+ /** The PolarSSL representation of the key data */
pk_context m_Pk;
/** The random generator used in encryption and decryption */
@@ -69,7 +69,7 @@ protected:
pk_context * GetInternal(void) { return &m_Pk; }
} ;
-typedef SharedPtr<cPublicKey> cPublicKeyPtr;
+typedef SharedPtr<cCryptoKey> cCryptoKeyPtr;
@@ -1,7 +1,7 @@
-// PublicKey.h
+// CryptoKey.h
-// Declares the cPublicKey class representing a RSA public key in PolarSSL
+// Declares the cCryptoKey class representing a RSA public key in PolarSSL